%define major     0
%define libname   %mklibname aec %{major}
%define develname %mklibname aec -d

%define szmajor   2
%define libszname %mklibname sz %{szmajor}

Name:           libaec
Version:        1.0.4
Release:        %mkrel 2
Summary:        Adaptive Entropy Coding library
License:        BSD
Group:          System/Libraries
Url:            https://gitlab.dkrz.de/k202009/libaec
Source:         https://gitlab.dkrz.de/k202009/libaec/-/archive/v%{version}/%{name}-v%{version}.tar.gz

BuildRequires:  cmake

%description
Libaec provides fast loss-less compression of 1 up to 32 bit wide
signed or unsigned integers (samples). The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-2 and 120.0-G-2.

Libaec includes a free drop-in replacement for the SZIP
library (http://www.hdfgroup.org/doc_resource/SZIP).

#------------------------------------------------

%package -n     %{libname}
Summary:        Adaptive Entropy Coding library
Group:          System/Libraries

%description -n %{libname}
Libaec provides fast loss-less compression of 1 up to 32 bit wide
signed or unsigned integers (samples). The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-2 and 120.0-G-2.

Libaec includes a free drop-in replacement for the SZIP
library (http://www.hdfgroup.org/doc_resource/SZIP).

#------------------------------------------------

%package -n     %{libszname}
Summary:        Lossless compression library for scientific data
Group:          System/Libraries

%description -n %{libszname}
Libsz provides fast loss-less compression of 1 up to 32 bit wide
signed or unsigned integers (samples). The library achieves best
results for low entropy data as often encountered in space imaging
instrument data or numerical model output from weather or climate
simulations. While floating point representations are not directly
supported, they can also be efficiently coded by grouping exponents
and mantissa.

Libaec implements Golomb Rice coding as defined in the Space Data
System Standard documents 121.0-B-2 and 120.0-G-2.

Libaec includes a free drop-in replacement for the SZIP
library (http://www.hdfgroup.org/doc_resource/SZIP).

#------------------------------------------------

%package -n     %{develname}
Summary:        Development package for %{name}
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Requires:       %{libszname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       szlib-devel = %{version}-%{release}

%description -n %{develname}
Header files for development with %{name}.

#------------------------------------------------

%prep
%setup -q -n %{name}-v%{version}

%build
%cmake
%cmake_build

%install
%cmake_install

%check
#test data missing in tarball for check_szcomp and sampledata.sh
LD_LIBRARY_PATH=%{buildroot}%{_libdir} \
make -C build test ARGS="-E \(check_szcomp\|sampledata.sh\)"

%files
%doc README.md README.SZIP CHANGELOG.md
%license Copyright.txt doc/patent.txt
%{_bindir}/aec
%{_mandir}/man1/aec.*

%files -n %{libname}
%{_libdir}/libaec.so.%{major}{,.*}

%files -n %{libszname}
%{_libdir}/libsz.so.%{szmajor}{,.*}

%files -n %{develname}
%{_includedir}/*.h
%{_libdir}/lib*.so


%changelog
* Sat Feb 15 2020 daviddavid <daviddavid> 1.0.4-2.mga8
+ Revision: 1523234
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Tue Feb 12 2019 daviddavid <daviddavid> 1.0.4-1.mga7
+ Revision: 1365434
- new version: 1.0.4

* Wed Feb 06 2019 daviddavid <daviddavid> 1.0.3-1.mga7
+ Revision: 1363647
- new version: 1.0.3

* Sun Sep 23 2018 umeabot <umeabot> 1.0.2-2.mga7
+ Revision: 1298749
- Mageia 7 Mass Rebuild

* Fri May 04 2018 daviddavid <daviddavid> 1.0.2-1.mga7
+ Revision: 1226082
- initial package libaec

